@@ -50,7 +50,7 @@ JINJA2_FILTERS = {
     "addslashes": "django_jinja.builtins.filters.addslashes",
     "capfirst": "django_jinja.builtins.filters.capfirst",
     "escapejs": "django_jinja.builtins.filters.escapejs_filter",
-    # "fix_ampersands": "django_jinja.builtins.filters.fix_ampersands_filter",
+    "fix_ampersands": "django_jinja.builtins.filters.fix_ampersands_filter",
     "floatformat": "django_jinja.builtins.filters.floatformat",
     "iriencode": "django_jinja.builtins.filters.iriencode",
     "linenumbers": "django_jinja.builtins.filters.linenumbers",
@@ -183,8 +183,8 @@ class Environment(Environment):
         loader = getattr(settings, "JINJA2_LOADER", None)
         if loader is None:
             from django.template.loaders import app_directories
-            default_loader_dirs = (app_directories.app_template_dirs +
-                                   tuple(settings.TEMPLATE_DIRS))
+            default_loader_dirs = (tuple(settings.TEMPLATE_DIRS) +
+                                   app_directories.app_template_dirs)
 
             self.loader = FileSystemLoader(default_loader_dirs)
         elif isinstance(loader, six.string_types):
